==> rendition-14.3.0.tgz: package/dist_esm5/components/Spinner/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import { rotate360 } from '../../animations';
import asRendition from '../../asRendition';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Txt from '../Txt';
var CircleLoader = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tbackground: transparent !important;\n\twidth: ", ";\n\theight: ", ";\n\tborder: ", " solid;\n\tcolor: ", ";\n\tborder-radius: 100%;\n\tborder-bottom-color: transparent;\n\tdisplay: inline-block;\n\tanimation: ", " 1s 0s infinite linear;\n\tanimation-fill-mode: both;\n"], ["\n\tbackground: transparent !important;\n\twidth: ", ";\n\theight: ", ";\n\tborder: ", " solid;\n\tcolor: ", ";\n\tborder-radius: 100%;\n\tborder-bottom-color: transparent;\n\tdisplay: inline-block;\n\tanimation: ", " 1s 0s infinite linear;\n\tanimation-fill-mode: both;\n"])), function (props) { return px(props.emphasized ? 40 : 20); }, function (props) { return px(props.emphasized ? 40 : 20); }, function (props) { return px(props.emphasized ? 6 : 4); }, function (props) { return props.theme.colors.quartenary.main; }, rotate360);
var Container = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var SpinnerContainer = styled(Flex)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\tz-index: 4;\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\tz-index: 4;\n"])));
var ChildrenContainer = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\topacity: ", ";\n\ttransition: opacity 250ms;\n\tz-index: 3;\n"], ["\n\topacity: ", ";\n\ttransition: opacity 250ms;\n\tz-index: 3;\n"])), function (props) { return (props.show ? 0.4 : 1); });
var SpinnerBase = function (_a) {
    var label = _a.label, emphasized = _a.emphasized, otherProps = __rest(_a, ["label", "emphasized"]);
    return (React.createElement(Flex, __assign({ flexDirection: emphasized ? 'column' : 'row', justifyContent: "center", alignItems: "center" }, otherProps),
        React.createElement(CircleLoader, { emphasized: emphasized }),
        label && (React.createElement(Txt, { color: "text.light", ml: emphasized ? 0 : 2, mt: emphasized ? 2 : 0 }, label))));
};
var Spinner = function (_a) {
    var _b = _a.show, show = _b === void 0 ? true : _b, emphasized = _a.emphasized, label = _a.label, children = _a.children, otherProps = __rest(_a, ["show", "emphasized", "label", "children"]);
    if (!children) {
        if (!show) {
            return null;
        }
        return (React.createElement(SpinnerBase, __assign({ label: label, emphasized: emphasized }, otherProps)));
    }
    return (React.createElement(Container, __assign({}, otherProps),
        show && (React.createElement(SpinnerContainer, { justifyContent: "center", alignItems: "center" },
            React.createElement(SpinnerBase, { label: label, emphasized: emphasized }))),
        React.createElement(ChildrenContainer, { show: show }, children)));
};
export default asRendition(Spinner);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;

==> rendition-14.9.0.tgz: package/dist_esm5/components/Spinner/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import { rotate360 } from '../../animations';
import asRendition from '../../asRendition';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Txt from '../Txt';
var CircleLoader = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tbackground: transparent !important;\n\twidth: ", ";\n\theight: ", ";\n\tborder: ", " solid;\n\tcolor: ", ";\n\tborder-radius: 100%;\n\tborder-bottom-color: transparent;\n\tdisplay: inline-block;\n\tanimation: ", " 1s 0s infinite linear;\n\tanimation-fill-mode: both;\n"], ["\n\tbackground: transparent !important;\n\twidth: ", ";\n\theight: ", ";\n\tborder: ", " solid;\n\tcolor: ", ";\n\tborder-radius: 100%;\n\tborder-bottom-color: transparent;\n\tdisplay: inline-block;\n\tanimation: ", " 1s 0s infinite linear;\n\tanimation-fill-mode: both;\n"])), function (props) { return px(props.emphasized ? 40 : 20); }, function (props) { return px(props.emphasized ? 40 : 20); }, function (props) { return px(props.emphasized ? 6 : 4); }, function (props) { return props.theme.colors.tertiary.main; }, rotate360);
var Container = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: relative;\n"], ["\n\tposition: relative;\n"])));
var SpinnerContainer = styled(Flex)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\tz-index: 4;\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\tz-index: 4;\n"])));
var ChildrenContainer = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\topacity: ", ";\n\ttransition: opacity 250ms;\n\tz-index: 3;\n"], ["\n\topacity: ", ";\n\ttransition: opacity 250ms;\n\tz-index: 3;\n"])), function (props) { return (props.show ? 0.4 : 1); });
var SpinnerBase = function (_a) {
    var label = _a.label, emphasized = _a.emphasized, otherProps = __rest(_a, ["label", "emphasized"]);
    return (React.createElement(Flex, __assign({ flexDirection: emphasized ? 'column' : 'row', justifyContent: "center", alignItems: "center", width: "fit-content" }, otherProps),
        React.createElement(CircleLoader, { emphasized: emphasized }),
        label && (React.createElement(Txt, { color: "text.light", ml: emphasized ? 0 : 2, mt: emphasized ? 2 : 0 }, label))));
};
var Spinner = function (_a) {
    var _b = _a.show, show = _b === void 0 ? true : _b, emphasized = _a.emphasized, label = _a.label, children = _a.children, otherProps = __rest(_a, ["show", "emphasized", "label", "children"]);
    if (!children) {
        if (!show) {
            return null;
        }
        return (React.createElement(SpinnerBase, __assign({ label: label, emphasized: emphasized }, otherProps)));
    }
    return (React.createElement(Container, __assign({}, otherProps),
        show && (React.createElement(SpinnerContainer, { justifyContent: "center", alignItems: "center" },
            React.createElement(SpinnerBase, { label: label, emphasized: emphasized }))),
        React.createElement(ChildrenContainer, { show: show }, children)));
};
export default asRendition(Spinner);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;
